/////////////////////////////////////////////////////////////////////////////////

// Original obtained from ShaderToy.com
// Adapted, trivialy, for VGHD by TheEmu.

uniform float u_Elapsed;    // The elapsed time in seconds
uniform vec2  u_WindowSize; // Window dimensions in pixels

// Use defines here rather than edit the body of the code.

#define iGlobalTime u_Elapsed
#define iResolution u_WindowSize
#define iMouse AUTO_MOUSE

/////////////////////////////////////////////////////////////////////////////////
// The ShaderToy shaders often use textures as inputs named iChannel0. With VGHD
// this may access a Sprite, ClipSprite or ClipNameSprite image depending on how
// the .scn file declares them.
//
// Note, the name used here does not seem to make any difference, so I have used
// iChannel0 which is what is used by ShaderToy but you can use any name as long
// as it matches the use in the main body of the shader. TheEmu.

uniform sampler2D iChannel0;

// With VGHD the range of the P argument's components of the texture functions is
// 0.0 to 1.0 whereas with ShaderToy it seems that the upper limits are given  by
// the number of pixels in each direction, typically 512 or 64.  We therefore use
// the following functions instead.

vec4 texture2D_Fract(sampler2D sampler,vec2 P) {return texture2D(sampler,fract(P));}
vec4 texture2D_Fract(sampler2D sampler,vec2 P, float Bias) {return texture2D(sampler,fract(P),Bias);}

// Rather than edit the body of the original shader we use use a define  here  to
// redirect texture calls to the above functions.

#define texture2D texture2D_Fract

/////////////////////////////////////////////////////////////////////////////////


void main ( void )
{
	 vec2 uv = gl_TexCoord[0].xy;
    vec2 neighbor = vec2(6.0) / textureSize(iChannel0,0);
    
    vec4 mainColor = texture2D( iChannel0, uv );
    vec4 npxColor = texture2D( iChannel0, uv+vec2( -neighbor.x, -neighbor.y)  );
    npxColor += texture2D( iChannel0, uv+vec2( -neighbor.x, neighbor.y)  );
    npxColor += texture2D( iChannel0, uv+vec2( neighbor.x, -neighbor.y)  );
    npxColor += texture2D( iChannel0, uv+vec2( neighbor.x, neighbor.y)  );
    npxColor /= 4.0;
    
    float offset = 0.01;
    
    bool isLessThan = any( lessThan( mainColor+offset, npxColor ) );
    
    gl_FragColor.rgb = isLessThan ? (mainColor.rgb*0.4) : (mainColor.rgb*1.2);
    gl_FragColor.a = mainColor.a;
}